<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ" sourcelanguage="en">
<context>
    <name>BlackoutWidget</name>
    <message>
        <source>Click to Return to Application</source>
        <translation>Chcete-li se vrátit do aplikace, klikněte sem</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>0 Items</source>
        <translation>0 položek</translation>
    </message>
    <message>
        <source>Clean Up</source>
        <translation>Vymazat</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Stáhnout</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation>Formulář</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otevřít</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zastavit</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Název souboru</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Zkusit znovu</translation>
    </message>
</context>
<context>
    <name>IntranetPodcastPublishingDialog</name>
    <message>
        <source>Title</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Publikovat podcast na YouTube</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Add</source>
        <translation>Přidat</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Vymazat</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Vyjmout</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Pero</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Tmavá</translation>
    </message>
    <message>
        <source>Hand</source>
        <translation>Ruka</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Domů</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Vlevo</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Čára</translation>
    </message>
    <message>
        <source>Next</source>
        <translatorcomment>strana</translatorcomment>
        <translation>Další</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Znovu</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Ukončit</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <source>Display Board</source>
        <translation>Zobrazit tabuli</translation>
    </message>
    <message>
        <source>Board</source>
        <translation>Tabule</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="vanished">Barva</translation>
    </message>
    <message>
        <source>Erase</source>
        <translation>Guma</translation>
    </message>
    <message>
        <source>Display Tools</source>
        <translation>Zobrazit nástroje</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Světlá</translation>
    </message>
    <message>
        <source>Embed Web Content</source>
        <translation>Vložit obsah z webu</translation>
    </message>
    <message>
        <source>Pages</source>
        <translation>Stránky</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Vložit</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pozastavit</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Vpravo</translation>
    </message>
    <message>
        <source>Sleep</source>
        <translation>Uspat</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Nástroje</translation>
    </message>
    <message>
        <source>Multi Screen</source>
        <translation>Víceobrazovkový mód</translation>
    </message>
    <message>
        <source>Put Presentation to Sleep</source>
        <translation>Uspat prezentaci</translation>
    </message>
    <message>
        <source>New Document</source>
        <translation>Nový dokument</translation>
    </message>
    <message>
        <source>Plain Dark Background</source>
        <translation>Černé pozadí</translation>
    </message>
    <message>
        <source>Podcast Config</source>
        <translation>Nastavení podcastu</translation>
    </message>
    <message>
        <source>Check Update</source>
        <translation>Vyhledat aktualizace</translation>
    </message>
    <message>
        <source>Use Custom Document Size</source>
        <translation>Použít vlastní velikost dokumentu</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>Přiblížit</translation>
    </message>
    <message>
        <source>Record Presentation to Video</source>
        <translation>Zaznamenat prezentaci jako video</translation>
    </message>
    <message>
        <source>Grid Dark Background</source>
        <translation>Mřížka s černým pozadím</translation>
    </message>
    <message>
        <source>Large Eraser</source>
        <translation>Velká guma</translation>
    </message>
    <message>
        <source>Grid Light Background</source>
        <translation>Mřížka s bílým pozadím</translation>
    </message>
    <message>
        <source>Hide OpenBoard Application</source>
        <translation>Skrýt aplikaci OpenBoard</translation>
    </message>
    <message>
        <source>Import an External Page</source>
        <translation>Otevřít externí stránku</translation>
    </message>
    <message>
        <source>Add Bookmark</source>
        <translation>Přidat záložku</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation>OpenBoard</translation>
    </message>
    <message>
        <source>Clear All Elements</source>
        <translation>Vymazat všechny objekty</translation>
    </message>
    <message>
        <source>Scroll Page</source>
        <translation>Posun po stránce</translation>
    </message>
    <message>
        <source>Small Line</source>
        <translation>Tenká čára</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Knihovna</translation>
    </message>
    <message>
        <source>Configure Podcast Recording</source>
        <translation>Nastavit záznam podastu</translation>
    </message>
    <message>
        <source>Open Page in Board</source>
        <translation>Otevřít stránku na tabuli</translation>
    </message>
    <message>
        <source>Bigger</source>
        <translation>Větší</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <source>Eraser</source>
        <translation>Vygumovat</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportovat</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Nová složka</translation>
    </message>
    <message>
        <source>Trap Flash Content</source>
        <translation>Přenést obsah ve Flashi</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Otevřít</translation>
    </message>
    <message>
        <source>Custom Capture</source>
        <translation>Vlastní způsob zachytávání</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Zvýrazňovač</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Create a New Document</source>
        <translation>Vytvořit nový dokument</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Nahrávat</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Obnovit</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Přejmenovat</translation>
    </message>
    <message>
        <source>Stylus</source>
        <translation>Stylus</translation>
    </message>
    <message>
        <source>Quit OpenBoard</source>
        <translation>Ukončit OpenBoard</translation>
    </message>
    <message>
        <source>Custom Size</source>
        <translation>Vlastní velikost</translation>
    </message>
    <message>
        <source>Laser Pointer</source>
        <translation>Laserové ukazovátko</translation>
    </message>
    <message>
        <source>Wide Size (16/9)</source>
        <translation>Na šířku (16/9)</translation>
    </message>
    <message>
        <source>Load Home Page</source>
        <translation>Nahrát domovskou stránku</translation>
    </message>
    <message>
        <source>Duplicate Page</source>
        <translation>Duplikovat stránku</translation>
    </message>
    <message>
        <source>Duplicate Selected Content</source>
        <translation>Duplikovat vybraný obsah</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Záložky</translation>
    </message>
    <message>
        <source>Open in Board</source>
        <translation>Otevřít na tabuli</translation>
    </message>
    <message>
        <source>Rename Content</source>
        <translation>Přejmenovat obsah</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Oddálit</translation>
    </message>
    <message>
        <source>Bookmark</source>
        <translation>Záložka</translation>
    </message>
    <message>
        <source>Add To Current Page</source>
        <translation>Přidat na aktuální stránku</translation>
    </message>
    <message>
        <source>Create a New Page</source>
        <translation>Vytvořit novou stránku</translation>
    </message>
    <message>
        <source>Hide OpenBoard</source>
        <translation>Skrýt OpenBoard</translation>
    </message>
    <message>
        <source>Erase All Items</source>
        <translation>Odstranit všechny položky</translation>
    </message>
    <message>
        <source>Erase Content</source>
        <translation>Odstranit obsah</translation>
    </message>
    <message>
        <source>Erase Items</source>
        <translation>Odstranit položky</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplikovat</translation>
    </message>
    <message>
        <source>Add Selected Content to Open Document</source>
        <translation>Přidat vybraný obsah do otevřeného dokumentu</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Virtuální klávesnice</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Podcast</translation>
    </message>
    <message>
        <source>Show Library</source>
        <translation>Zobrazit knihovnu</translation>
    </message>
    <message>
        <source>Medium Eraser</source>
        <translation>Středně velká guma</translation>
    </message>
    <message>
        <source>Stop Loading Web Page</source>
        <translation>Zastavit nahrávání stránky</translation>
    </message>
    <message>
        <source>Duplicate the Current Page</source>
        <translation>Duplikovat aktuální stránku</translation>
    </message>
    <message>
        <source>Pause Podcast Recording</source>
        <translation>Pozastavit nahrávání podcastu</translation>
    </message>
    <message>
        <source>Create a New Folder</source>
        <translation>Vytvořit novou složku </translation>
    </message>
    <message>
        <source>Clear Page</source>
        <translation>Vymazat stránku</translation>
    </message>
    <message>
        <source>Add To Library</source>
        <translation>Přidat do knihovny</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Předchozí</translation>
    </message>
    <message>
        <source>Stop Loading</source>
        <translation>Zastavit nahrávání</translation>
    </message>
    <message>
        <source>Reload Current Page</source>
        <translation>Obnovit aktuální stránku</translation>
    </message>
    <message>
        <source>Import Page</source>
        <translation>Otevřít stránku</translation>
    </message>
    <message>
        <source>Draw Lines</source>
        <translation>Nakreslit čáry</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>Zachytit</translation>
    </message>
    <message>
        <source>Show Main Screen on Display Screen</source>
        <translation>V zobrazené části obrazovky zobrazit hlavní obrazovku</translation>
    </message>
    <message>
        <source>Flash Trap</source>
        <translation>Přenést Flash</translation>
    </message>
    <message>
        <source>Window Capture</source>
        <translation>Zachytit okno</translation>
    </message>
    <message>
        <source>Delete Selected Content</source>
        <translation>Odstranit vybraný obsah</translation>
    </message>
    <message>
        <source>Add Item To New Page</source>
        <translation>Přidat položku na novou stránku</translation>
    </message>
    <message>
        <source>Add Content to Document</source>
        <translation>Přidat obsah do dokumentu</translation>
    </message>
    <message>
        <source>Smaller</source>
        <translation>Menší</translation>
    </message>
    <message>
        <source>Capture Embeddable Web Content</source>
        <translation>Zachytit část webové stránky</translation>
    </message>
    <message>
        <source>Write Text</source>
        <translation>Napsat text</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenty</translation>
    </message>
    <message>
        <source>Add To New Page</source>
        <translation>Přidat na novou stránku</translation>
    </message>
    <message>
        <source>Regular Size (4/3)</source>
        <translation>Bežná velikost (4/3)</translation>
    </message>
    <message>
        <source>Web Trap</source>
        <translation>Přenést web</translation>
    </message>
    <message>
        <source>Display Virtual Keyboard</source>
        <translation>Zobrazit virtuální klávesnici</translation>
    </message>
    <message>
        <source>Show Bookmarks</source>
        <translation>Zobrazit záložky</translation>
    </message>
    <message>
        <source>Use Document Wide Size (16/9)</source>
        <translation>Používat dokument na šířku (16/9)</translation>
    </message>
    <message>
        <source>Show Computer Desktop</source>
        <translation>Zobrazit plochu</translation>
    </message>
    <message>
        <source>eduMedia</source>
        <translation>eduMedia</translation>
    </message>
    <message>
        <source>Medium Line</source>
        <translation>Středně široká čára</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>Předchozí stránka</translation>
    </message>
    <message>
        <source>Trap Web Content</source>
        <translation>Přenést obsah z webu</translation>
    </message>
    <message>
        <source>Selector</source>
        <translation>Oddělovač</translation>
    </message>
    <message>
        <source>Erase all Annotations</source>
        <translation>Vymazat všechny anotace</translation>
    </message>
    <message>
        <source>Erase All Annotations</source>
        <translation>Vymazat všechny anotace</translation>
    </message>
    <message>
        <source>Export a Document</source>
        <translation>Exportovat dokument</translation>
    </message>
    <message>
        <source>Start Screen Recording</source>
        <translation>Spustit nahrávání obrazovky</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation>Nová stránka</translation>
    </message>
    <message>
        <source>Import a Document</source>
        <translation>Otevřít dokument</translation>
    </message>
    <message>
        <source>Import eduMedia simulation</source>
        <translation>Nahrát simulaci z webu eduMedia</translation>
    </message>
    <message>
        <source>Use Document Regular Size (4/3)</source>
        <translation>Používat běžnou velikost dokumentu (4/3)</translation>
    </message>
    <message>
        <source>Change Background</source>
        <translation>Změnit pozadí</translation>
    </message>
    <message>
        <source>Display Preferences</source>
        <translation>Zobrazit předvolby</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>Předvolby</translation>
    </message>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Zachytit část obrazovky</translation>
    </message>
    <message>
        <source>Ctrl+Shift+H</source>
        <translation>Ctrl+Shift+H</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Vpřed</translation>
    </message>
    <message>
        <source>Manage Documents</source>
        <translation>Spravovat dokumenty</translation>
    </message>
    <message>
        <source>Large Line</source>
        <translation>Široká čára</translation>
    </message>
    <message>
        <source>Erase Annotations</source>
        <translation>Vymazat anotace</translation>
    </message>
    <message>
        <source>Show on Display</source>
        <translation>Zobrazit při projekcii</translation>
    </message>
    <message>
        <source>Select And Modify Objects</source>
        <translation>Vybrat a upravit objekty</translation>
    </message>
    <message>
        <source>Capture a Window</source>
        <translation>Zachytit okno</translation>
    </message>
    <message>
        <source>Virtual Laser Pointer</source>
        <translation>Virtuální laserové ukazovátko</translation>
    </message>
    <message>
        <source>Plain Light Background</source>
        <translation>Bílé pozadí</translation>
    </message>
    <message>
        <source>Add Item To Library</source>
        <translation>Přidat položku do knihovny</translation>
    </message>
    <message>
        <source>Web Browsing</source>
        <translation>Prohlížet web</translation>
    </message>
    <message>
        <source>Backgrounds</source>
        <translation>Pozadí</translation>
    </message>
    <message>
        <source>Smalle Eraser</source>
        <translation type="vanished">Malá guma</translation>
    </message>
    <message>
        <source>Add Item To Current Page</source>
        <translation>Přidat položku na aktuální stránku</translation>
    </message>
    <message>
        <source>Add to Working Document</source>
        <translation>Přidat do aktuálního dokumentu</translation>
    </message>
    <message>
        <source>Highlight </source>
        <translation>Zvýraznit </translation>
    </message>
    <message>
        <source>Show Desktop</source>
        <translation>Plocha</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>Další stránka</translation>
    </message>
    <message>
        <source>Annotate Document</source>
        <translation>Přidat anotaci dokumentu</translation>
    </message>
    <message>
        <source>Erase Annotation</source>
        <translation>Vymazat anotaci</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Přehrát</translation>
    </message>
    <message>
        <source>Interact with items</source>
        <translation>Pracovat s položkami</translation>
    </message>
    <message>
        <source>Erase Background</source>
        <translation>Vymazat pozadí</translation>
    </message>
    <message>
        <source>Remove the backgound</source>
        <translation>Odstranit pozadí</translation>
    </message>
    <message>
        <source>Ruled Light Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ruled Dark Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Tutorial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open the tutorial web page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset grid size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small Eraser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Vyžaduje se přihlášení</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Heslo:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Uživatelské jméno:</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Save username and password for future use</source>
        <translation>Uložit uživatelské jméno a heslo pro budoucí použití</translation>
    </message>
    <message>
        <source>Connect to Proxy</source>
        <translation>Připojit se k proxy</translation>
    </message>
    <message>
        <source>Proxy Authentication</source>
        <translation>Přihlášení na proxy</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Heslo:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Uživatelské jméno:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Element ID = </source>
        <translation type="unfinished">ID objektu = </translation>
    </message>
    <message>
        <source>Content is not supported in destination format.</source>
        <translation>Obsah není podporován v cílovém formátu.</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation>Odstranit stránku</translation>
    </message>
    <message>
        <source>Are you sure you want to remove 1 page from the selected document &apos;%0&apos;?</source>
        <translation>Opravdu chcete odstranit 1 stránku z vybraného dokumentu &apos;%0&apos;?</translation>
    </message>
</context>
<context>
    <name>UBApplication</name>
    <message>
        <source>Podcast</source>
        <translation>Podcast</translation>
    </message>
    <message>
        <source>Page Size</source>
        <translation>Velikost stránky</translation>
    </message>
</context>
<context>
    <name>UBApplicationController</name>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Akutalizovat</translation>
    </message>
    <message>
        <source>No update available</source>
        <translation>Žádná aktualizace není k dispozicii</translation>
    </message>
    <message>
        <source>New update available, would you go to the web page ?</source>
        <translation>K dispozici je nová aktualizace, chcete přejít na webovou stránku?</translation>
    </message>
    <message>
        <source>Update available</source>
        <translation>K dispozici je aktualizace</translation>
    </message>
</context>
<context>
    <name>UBBackgroundPalette</name>
    <message>
        <source>Grid size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBBoardController</name>
    <message>
        <source>All Supported (%1)</source>
        <translation>Všechny podporované (%1)</translation>
    </message>
    <message>
        <source>Downloading content %1 failed</source>
        <translation>Nepodařilo se stáhnout %1</translation>
    </message>
    <message>
        <source>Unknown content type %1</source>
        <translation>Neznámy typ obsahu (%1)</translation>
    </message>
    <message>
        <source>Add Item</source>
        <translation>Přidat položku</translation>
    </message>
    <message>
        <source>Unknown tool type %1</source>
        <translation>Neznámý typ nástroje %1</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Stahování dokončeno</translation>
    </message>
    <message>
        <source>Delete page %1 from document</source>
        <translation type="vanished">Odstranit stránku %1 z dokumentu</translation>
    </message>
    <message>
        <source>Page %1 deleted</source>
        <translation>Stránka %1 byla odstraněna</translation>
    </message>
    <message>
        <source>Add file operation failed: file copying error</source>
        <translation>Přidání souboru selhalo: chyba při kopírování</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Seskupit</translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation>Odseskupit</translation>
    </message>
    <message>
        <source>Saving document...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document has just been saved...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting page %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="unfinished">Barva</translation>
    </message>
</context>
<context>
    <name>UBBoardPaletteManager</name>
    <message>
        <source>Error Adding Image to Library</source>
        <translation>Chyba při přidávání obrázku do knihovny</translation>
    </message>
    <message>
        <source>CapturedImage</source>
        <translation>Zachycenýobrázek</translation>
    </message>
</context>
<context>
    <name>UBBoardThumbnailsView</name>
    <message>
        <source>Loading page (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBCachePropertiesWidget</name>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Velikost:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Barva:</translation>
    </message>
    <message>
        <source>Shape:</source>
        <translation>Tvar:</translation>
    </message>
    <message>
        <source>Cache Properties</source>
        <translation>Vlastnosti baterky</translation>
    </message>
</context>
<context>
    <name>UBDesktopPalette</name>
    <message>
        <source>Show Desktop on Secondary Screen</source>
        <translation>Zobrazit plochu na druhé obrazovce</translation>
    </message>
    <message>
        <source>Capture the Screen</source>
        <translation>Zachytit obrazovku</translation>
    </message>
    <message>
        <source>Show the stylus palette</source>
        <translation>Zobrazit paletu pro stylus</translation>
    </message>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Zachytit část obrazovky</translation>
    </message>
    <message>
        <source>Show Board on Secondary Screen</source>
        <translation>Zobrazit tabuli na druhé obrazovce</translation>
    </message>
    <message>
        <source>Show OpenBoard</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentController</name>
    <message>
        <source>Empty</source>
        <translation>Vyprázdnit</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Koš</translation>
    </message>
    <message>
        <source>Are you sure you want to empty trash?</source>
        <translation type="vanished">Určitě chcete vyprázdnit koš?</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the folder &apos;%1&apos; and all its content?</source>
        <translation type="vanished">Určitě chcete odstranit složku &quot;%1&quot; a celý její obsah?</translation>
    </message>
    <message>
        <source>Open Supported File</source>
        <translation>Otevřít podporovaný soubor</translation>
    </message>
    <message>
        <source>Remove Document</source>
        <translation type="vanished">Odstranit dokument</translation>
    </message>
    <message>
        <source>All Images (%1)</source>
        <translation>Všechny obrázky (%1)</translation>
    </message>
    <message>
        <source>Selection does not contain any image files!</source>
        <translation>Ve výběru není žádný soubor obrázku!</translation>
    </message>
    <message>
        <source>Open Document</source>
        <translation>Otevřít dokument</translation>
    </message>
    <message>
        <source>Add Folder of Images</source>
        <translation>Přidat složku s obrázky</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Nová složka</translation>
    </message>
    <message>
        <source>Add Images</source>
        <translation>Přidat obrázky</translation>
    </message>
    <message>
        <source>Duplicating Document %1</source>
        <translation>Duplikuje se dokument %1</translation>
    </message>
    <message>
        <source>Page %1</source>
        <translation>Stránka %1</translation>
    </message>
    <message>
        <source>Document %1 copied</source>
        <translation>Dokument %1 byl zkopírovaný</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>Otevírá se soubor %1...</translation>
    </message>
    <message>
        <source>Failed to import file ... </source>
        <translation>Soubor se nepodařilo otevřít...</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the document &apos;%1&apos;?</source>
        <translation type="vanished">Určitě chcete odstranit dokument &quot;%1&quot;?</translation>
    </message>
    <message>
        <source>Emptied trash</source>
        <translation type="vanished">Koš byl vyprázdněn</translation>
    </message>
    <message>
        <source>Empty Trash</source>
        <translation type="vanished">Vyprázdnit koš</translation>
    </message>
    <message>
        <source>Remove Folder</source>
        <translation type="vanished">Odstranit složku</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation type="vanished">Odstranit stránku</translation>
    </message>
    <message>
        <source>No document selected!</source>
        <translation type="vanished">Nevybrali jste žádný dokument!</translation>
    </message>
    <message>
        <source>Import all Images from Folder</source>
        <translation>Nahrát všechny obrázky ze složky</translation>
    </message>
    <message>
        <source>Emptying trash</source>
        <translation type="vanished">Vyprazdňuje se koš</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to remove %n page(s) from the selected document &apos;%1&apos;?</source>
        <translation type="vanished">
            <numerusform>Určitě chcete odstranit %n stránku z vybraného dokumentu %1?</numerusform>
            <numerusform>Určitě chcete odstranit %n stránky z vybraného dokumentu %1?</numerusform>
            <numerusform>Určitě chcete odstranit %n stránek z vybraného dokumentu %1?</numerusform>
        </translation>
    </message>
    <message>
        <source>Add all Images to Document</source>
        <translation>Přidat všechny obrázky do dokumentu</translation>
    </message>
    <message>
        <source>Add Pages from File</source>
        <translation>Přidat stránky ze souboru</translation>
    </message>
    <message>
        <source>Folder does not contain any image files</source>
        <translation>Složka neobsahuje žádné obrázky</translation>
    </message>
    <message>
        <source>Untitled Documents</source>
        <translation>Dokumenty bez názvu</translation>
    </message>
    <message numerus="yes">
        <source>duplicated %1 page</source>
        <comment>duplicated %1 pages</comment>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The document &apos;%1&apos; has been generated with a newer version of OpenBoard (%2). By opening it, you may lose some information. Do you want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title page</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentManager</name>
    <message>
        <source>All supported files (*.%1)</source>
        <translation>Všechny podporované soubory (*.%1)</translation>
    </message>
    <message>
        <source>objects</source>
        <translation>objekty</translation>
    </message>
    <message>
        <source>images</source>
        <translation>obrázky</translation>
    </message>
    <message>
        <source>videos</source>
        <translation>videa</translation>
    </message>
    <message>
        <source>widgets</source>
        <translation>widgety</translation>
    </message>
    <message>
        <source>File %1 saved</source>
        <translation>Soubor %1 byl uložen</translation>
    </message>
    <message>
        <source>Inserting page %1 of %2</source>
        <translation>Vkládá se strana %1 z %2</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Import byl úspěšně dokončen.</translation>
    </message>
    <message>
        <source>Import of file %1 successful.</source>
        <translation>Import souboru %1 byl úspěšný.</translation>
    </message>
    <message>
        <source>Importing file %1</source>
        <translation>Importuje se soubor %1</translation>
    </message>
</context>
<context>
    <name>UBDocumentNavigator</name>
    <message>
        <source>Page %0</source>
        <translation>Stránka %0</translation>
    </message>
</context>
<context>
    <name>UBDocumentReplaceDialog</name>
    <message>
        <source>Accept</source>
        <translation type="unfinished">Přijmout</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Zrušit</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The name %1 is allready used.
Keeping this name will replace the document.
Providing a new name will create a new document.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeModel</name>
    <message>
        <source>Trash</source>
        <translation type="unfinished">Koš</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="unfinished">
            <numerusform>%1 zkopírovaná stránka</numerusform>
            <numerusform>%1 zkopírované stránky</numerusform>
            <numerusform>%1 zkopírovaných stránek</numerusform>
        </translation>
    </message>
    <message>
        <source>My documents</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeView</name>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="unfinished">
            <numerusform>%1 zkopírovaná stránka</numerusform>
            <numerusform>%1 zkopírované stránky</numerusform>
            <numerusform>%1 zkopírovaných stránek</numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="unfinished">Kopíruje se stránka %1/%2</translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeWidget</name>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="vanished">
            <numerusform>%1 zkopírovaná stránka</numerusform>
            <numerusform>%1 zkopírované stránky</numerusform>
            <numerusform>%1 zkopírovaných stránek</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 (copy)</source>
        <translation type="vanished">%1 (kopie)</translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="vanished">Kopíruje se stránka %1/%2</translation>
    </message>
</context>
<context>
    <name>UBDownloadWidget</name>
    <message>
        <source>Downloading files</source>
        <translation>Stahování souborů</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnail</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">Stránka %0</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnailView</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">Stránka %0</translation>
    </message>
</context>
<context>
    <name>UBExportAdaptor</name>
    <message>
        <source>Warnings during export was appeared</source>
        <translation>Během exportu se objevila varování</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished">Exportuje se dokument...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished">Export byl úspěšně dokončen.</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportCFF</name>
    <message>
        <source>Export to IWB</source>
        <translation>Export do IWB</translation>
    </message>
    <message>
        <source>Export as IWB File</source>
        <translation>Exportovat jako IWB soubor</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Exportuje se dokument...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Export byl úspěšně dokončen.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Export se nezdařil.</translation>
    </message>
</context>
<context>
    <name>UBExportDocument</name>
    <message>
        <source>Page</source>
        <translation>Stránka</translation>
    </message>
    <message>
        <source>Export as UBZ File</source>
        <translation>Exportovat jako soubor UBZ</translation>
    </message>
    <message>
        <source>Exporting %1 %2 of %3</source>
        <translation>Exportuje se %1 %2 z(e) %3</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Exportuje se dokument...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Export byl úspěšně dokončen.</translation>
    </message>
    <message>
        <source>Export to OpenBoard Format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportDocumentSetAdaptor</name>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished">Exportuje se dokument...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished">Export byl úspěšně dokončen.</translation>
    </message>
    <message>
        <source>Failed to export...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export as UBX File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export to OpenBoard UBX Format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportFullPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Exportovat jako soubor PDF</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>Exportovat do PDF</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Exportuje se dokument...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Export byl úspěšně dokončen.</translation>
    </message>
</context>
<context>
    <name>UBExportPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Exportovat jako soubor PDF</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>Exportovat do PDF</translation>
    </message>
    <message>
        <source>Exporting page %1 of %2</source>
        <translation>Exportuje se stránka %1 z(e) %2</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Exportuje se dokument...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Export byl úspěšně dokončen.</translation>
    </message>
</context>
<context>
    <name>UBExportWeb</name>
    <message>
        <source>Page</source>
        <translation>Stránka</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Export se nezdařill.</translation>
    </message>
    <message>
        <source>Export as Web data</source>
        <translation>Exportovat jako webová data</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Exportuje se dokument...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Export byl úspěšně dokončen.</translation>
    </message>
    <message>
        <source>Export to Web Browser</source>
        <translation>Exportovat do webového prohlížeče</translation>
    </message>
</context>
<context>
    <name>UBFeatureProperties</name>
    <message>
        <source>Add to page</source>
        <translation>Přidat na stránku</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="vanished">Nastavit jako pozadí</translation>
    </message>
    <message>
        <source>Add to library</source>
        <translation>Přidat do knihovny</translation>
    </message>
    <message>
        <source>Object informations</source>
        <translation>Informace o objektu</translation>
    </message>
</context>
<context>
    <name>UBFeaturesActionBar</name>
    <message>
        <source>Add to favorites</source>
        <translation>Přidat do oblíbených položek</translation>
    </message>
    <message>
        <source>Share</source>
        <translation>Sdílet</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <source>Back to folder</source>
        <translation>Zpět na složku</translation>
    </message>
    <message>
        <source>Remove from favorites</source>
        <translation>Odstranit z oblíbených položek</translation>
    </message>
    <message>
        <source>Create new folder</source>
        <translation>Vytvořit novou složku</translation>
    </message>
    <message>
        <source>Rescan file system</source>
        <translation>Znovu prověřit souborový systém</translation>
    </message>
</context>
<context>
    <name>UBFeaturesController</name>
    <message>
        <source>ImportedImage</source>
        <translation>NahranýObrázek</translation>
    </message>
    <message>
        <source>Audios</source>
        <translation>Zvuky</translation>
    </message>
    <message>
        <source>Movies</source>
        <translation>Filmy</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Obrázky</translation>
    </message>
    <message>
        <source>Animations</source>
        <translation type="vanished">Animace</translation>
    </message>
    <message>
        <source>Interactivities</source>
        <translation>Interaktivity</translation>
    </message>
    <message>
        <source>Applications</source>
        <translation>Aplikace</translation>
    </message>
    <message>
        <source>Shapes</source>
        <translation>Tvary</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Oblíbené</translation>
    </message>
    <message>
        <source>Web search</source>
        <translation>Webové vyhledávače</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Koš</translation>
    </message>
</context>
<context>
    <name>UBFeaturesNewFolderDialog</name>
    <message>
        <source>Accept</source>
        <translation>Přijmout</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Enter a new folder name</source>
        <translation>Zapsat název nové složky</translation>
    </message>
</context>
<context>
    <name>UBFeaturesProgressInfo</name>
    <message>
        <source>Loading </source>
        <translation>Nahrává se </translation>
    </message>
</context>
<context>
    <name>UBGraphicsGroupContainerItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>Uzamčeno</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Viditelné na rozšířené obrazovce</translation>
    </message>
</context>
<context>
    <name>UBGraphicsItemDelegate</name>
    <message>
        <source>Go to Content Source</source>
        <translation>Přejít na zdroj</translation>
    </message>
    <message>
        <source>Locked</source>
        <translation>Uzamčeno</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Viditelné na rozšířené obrazovce</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="unfinished">Nastavit jako pozadí</translation>
    </message>
</context>
<context>
    <name>UBGraphicsMediaItem</name>
    <message>
        <source>Media resource couldn&apos;t be resolved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsupported media format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media playback service not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media error: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItem</name>
    <message>
        <source>&lt;Type Text Here&gt;</source>
        <translation>&lt;Sem napište text&gt;</translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItemDelegate</name>
    <message>
        <source>Text Color</source>
        <translation>Barva textu</translation>
    </message>
    <message>
        <source>Editable</source>
        <translation>Upravitelný</translation>
    </message>
</context>
<context>
    <name>UBGraphicsW3CWidgetItem</name>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItem</name>
    <message>
        <source>Loading ...</source>
        <translation>Nahrává se...</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItemDelegate</name>
    <message>
        <source>Frozen</source>
        <translation>Zamrzlé</translation>
    </message>
    <message>
        <source>Transform as Tool </source>
        <translation>Změnit na nástroj</translation>
    </message>
</context>
<context>
    <name>UBImportCFF</name>
    <message>
        <source>Importing file %1...</source>
        <translation>Importuje se soubor %1...</translation>
    </message>
    <message>
        <source>Import failed.</source>
        <translation>Import se nezdařil.</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>Import souboru %1 se nezdařil.</translation>
    </message>
    <message>
        <source>Common File Format (</source>
        <translation>Univerzální IWB soubor (</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Import byl úspěšně dokončen.</translation>
    </message>
</context>
<context>
    <name>UBImportDocument</name>
    <message>
        <source>Importing file %1...</source>
        <translation>Importuje se soubor %1...</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>Import souboru %1 se nezdařil.</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Import byl úspěšně dokončen.</translation>
    </message>
    <message>
        <source>OpenBoard (*.ubz)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportDocumentSetAdaptor</name>
    <message>
        <source>Openboard (set of documents) (*.ubx)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportImage</name>
    <message>
        <source>Image Format (</source>
        <translation>Soubor obrázku (</translation>
    </message>
</context>
<context>
    <name>UBImportPDF</name>
    <message>
        <source>PDF import failed.</source>
        <translation>Import do PDF selhal.</translation>
    </message>
    <message>
        <source>Importing page %1 of %2</source>
        <translation>Importuje se stránka %1 z(e) %2</translation>
    </message>
    <message>
        <source>Portable Document Format (*.pdf)</source>
        <translation>Portable Document Format (*.pdf)</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublisher</name>
    <message>
        <source>Publishing to Intranet in progress %1 %</source>
        <translation>Probíhá publikování na intranet %1 %</translation>
    </message>
    <message>
        <source>Error while publishing video to intranet (%1)</source>
        <translation>Chyba při publikovaní videa na intranet (%1)</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish</source>
        <translation>Publikovat</translation>
    </message>
</context>
<context>
    <name>UBKeyboardPalette</name>
    <message>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
</context>
<context>
    <name>UBMainWindow</name>
    <message>
        <source>No</source>
        <translation>Ne</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ano</translation>
    </message>
</context>
<context>
    <name>UBMessagesDialog</name>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
</context>
<context>
    <name>UBNetworkAccessManager</name>
    <message>
        <source>No</source>
        <translation>Ne</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ano</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Zadajte uživatelské jméno a heslo pro &quot;%1&quot; na %2&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>Failed to log to Proxy</source>
        <translation>Nepodařilo se přihlásit na proxy</translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors for this host?</source>
        <translation>Chyby SSL:

%1

%2

Chcete ignorovat tyto chyby na tomto serveru?</translation>
    </message>
</context>
<context>
    <name>UBOpenSankoreImporterWidget</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Zrušit</translation>
    </message>
    <message>
        <source>Open-Sankore Documents Detected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open-Sankoré documents are present on your computer. It is possible to import them to OpenBoard by pressing the “Proceed” button to launch the importer application.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show this panel next time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can always access the OpenBoard Document Importer through the Preferences panel in the About tab. Warning, if you have already imported your Open-Sankore datas, you might loose your current OpenBoard documents.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proceed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPersistenceManager</name>
    <message>
        <source>(copy)</source>
        <translation>(kopie)</translation>
    </message>
    <message>
        <source>Document Repository Loss</source>
        <translation>Ztráta repozitáře s dokumenty</translation>
    </message>
    <message>
        <source>OpenBoard has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPlatformUtils</name>
    <message>
        <source>English</source>
        <translation>Angličtina</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>Ruština</translation>
    </message>
    <message>
        <source>German</source>
        <translation>Němčina</translation>
    </message>
    <message>
        <source>French</source>
        <translation>Francouzština</translation>
    </message>
    <message>
        <source>Swiss French</source>
        <translation>Švýcarská francouzština</translation>
    </message>
</context>
<context>
    <name>UBPodcastController</name>
    <message>
        <source>Full</source>
        <translation>Plná velikost</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Malá velikost</translation>
    </message>
    <message>
        <source>Podcast recording error (%1)</source>
        <translation>Chyba při nahrávaní podcastu (%1)</translation>
    </message>
    <message>
        <source>No Podcast encoder available ...</source>
        <translation>Žádný encoder podcastu není dostupný...</translation>
    </message>
    <message>
        <source>Publish to Youtube</source>
        <translation>Publikovat na Youtube</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Střední velikost</translation>
    </message>
    <message>
        <source>in folder %1</source>
        <translation>ve složce %1</translation>
    </message>
    <message>
        <source>Part %1</source>
        <translation>Část %1</translation>
    </message>
    <message>
        <source>Podcast created %1</source>
        <translation>Podcast vytvořen %1</translation>
    </message>
    <message>
        <source>No Audio Recording</source>
        <translation>Žádný zvukový záznam</translation>
    </message>
    <message>
        <source>Publish to Intranet</source>
        <translation>Publikovat na intranetu</translation>
    </message>
    <message>
        <source>on your desktop ...</source>
        <translation>na vaši pracovní plochu...</translation>
    </message>
    <message>
        <source>Default Audio Input</source>
        <translation>Výchozí vstupní audio zařízení</translation>
    </message>
    <message>
        <source>Failed to start encoder ...</source>
        <translation>Nepodařilo se spustit encoder...</translation>
    </message>
    <message>
        <source>OpenBoard Cast</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPreferencesController</name>
    <message>
        <source>version: </source>
        <translation>verze: </translation>
    </message>
    <message>
        <source>Marker is pressure sensitive</source>
        <translation>Zvýrazňovač je citlivý na tlak</translation>
    </message>
</context>
<context>
    <name>UBProxyLoginDlg</name>
    <message>
        <source>Password:</source>
        <translation type="vanished">Heslo:</translation>
    </message>
    <message>
        <source>Proxy Login</source>
        <translation type="vanished">Přihlášení na proxy</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="vanished">Uživatelské jméno:</translation>
    </message>
</context>
<context>
    <name>UBPublicationDlg</name>
    <message>
        <source>Description:</source>
        <translation type="vanished">Popis:</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="vanished">Název:</translation>
    </message>
    <message>
        <source>Publish</source>
        <translation type="vanished">Publikovat</translation>
    </message>
    <message>
        <source>Publish document on the web</source>
        <translation type="vanished">Publikovat dokument na webu</translation>
    </message>
</context>
<context>
    <name>UBSettings</name>
    <message>
        <source>My Movies</source>
        <translation>Moje filmy</translation>
    </message>
</context>
<context>
    <name>UBStartupHintsPalette</name>
    <message>
        <source>Visible next time</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBTeacherBarWidget</name>
    <message>
        <source></source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UBThumbnailAdaptor</name>
    <message>
        <source>%1 thumbnails generated ...</source>
        <translation>%1 vytvořených miniatur...</translation>
    </message>
    <message>
        <source>Generating preview thumbnails ...</source>
        <translation>Vytváří se miniatury obrázků ...</translation>
    </message>
</context>
<context>
    <name>UBThumbnailTextItem</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">Stránka %0</translation>
    </message>
</context>
<context>
    <name>UBToolsManager</name>
    <message>
        <source>Mask</source>
        <translation>Clona</translation>
    </message>
    <message>
        <source>Cache</source>
        <translation>Baterka</translation>
    </message>
    <message>
        <source>Ruler</source>
        <translation>Pravítko</translation>
    </message>
    <message>
        <source>Triangle</source>
        <translation>Trojúhelník</translation>
    </message>
    <message>
        <source>Compass</source>
        <translation>Kružítko</translation>
    </message>
    <message>
        <source>Protractor</source>
        <translation>Úhloměr</translation>
    </message>
    <message>
        <source>Magnifier</source>
        <translation>Lupa</translation>
    </message>
    <message>
        <source>Axes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBTrapFlashController</name>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
    <message>
        <source>Whole page</source>
        <translation>Celá stránka</translation>
    </message>
</context>
<context>
    <name>UBUpdateDlg</name>
    <message>
        <source>Document updater</source>
        <translation>Aktualizace dokumentu</translation>
    </message>
    <message>
        <source>Please wait the import process will start soon...</source>
        <translation>Prosím, počkejte, proces nahrávání brzy začne...</translation>
    </message>
    <message>
        <source>Files update successful!
Please reboot the application to access the updated documents.</source>
        <translation>Aktualizace proběhla úspěšně!
Znovu spusťte aplikaci, abyste mohli pracovat s aktualizovanými dokumenty.</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Procházet</translation>
    </message>
    <message>
        <source>Select a backup folder</source>
        <translation>Vyberte složku na zálohu</translation>
    </message>
    <message>
        <source> files require an update.</source>
        <translation> soubory je nutné aktualizovat.</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Aktualizovat</translation>
    </message>
    <message>
        <source>An error occured during the update. The files have not been affected.</source>
        <translation>Během aktualizace se vyskytla chyba. Soubory to neovlivnilo.</translation>
    </message>
    <message>
        <source>Files update results</source>
        <translation>Výsledky aktualizace souborů</translation>
    </message>
    <message>
        <source>Backup path: </source>
        <translation>Umístění zálohy: </translation>
    </message>
    <message>
        <source>Updating file </source>
        <translation>Aktualizuje se soubor</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Připomenout později</translation>
    </message>
</context>
<context>
    <name>UBWebPluginWidget</name>
    <message>
        <source>Loading...</source>
        <translation>Nahrává se...</translation>
    </message>
</context>
<context>
    <name>UBWidgetUniboardAPI</name>
    <message>
        <source>%0 called (method=%1, status=%2)</source>
        <translation>%0 vyvolané (metoda = %1, stav = %2)</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublisher</name>
    <message>
        <source>YouTube authentication failed.</source>
        <translation>Přihlášení na YouTube selhalo.</translation>
    </message>
    <message>
        <source>Error while uploading video to YouTube (%1)</source>
        <translation>Chyba při nahrávaní videa na YouTube (%1)</translation>
    </message>
    <message>
        <source>Upload to YouTube in progress %1 %</source>
        <translation>Probíhá nahrávaní na YouTube %1 %</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublishingDialog</name>
    <message>
        <source>Music</source>
        <translation>Hudba</translation>
    </message>
    <message>
        <source>People &amp; Blogs</source>
        <translation>Lidé a blogy</translation>
    </message>
    <message>
        <source>Nonprofits &amp; Activism</source>
        <translation>Neziskovky a aktivisti</translation>
    </message>
    <message>
        <source>Comedy</source>
        <translation>Komedie</translation>
    </message>
    <message>
        <source>Gaming</source>
        <translation>Hry</translation>
    </message>
    <message>
        <source>Sports</source>
        <translation>Sport</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Nahrát</translation>
    </message>
    <message>
        <source>Science &amp; Technology</source>
        <translation>Věda a technika</translation>
    </message>
    <message>
        <source>Howto &amp; Style</source>
        <translation>Návody a styl</translation>
    </message>
    <message>
        <source>Education</source>
        <translation>Vzdělávání</translation>
    </message>
    <message>
        <source>Entertainment</source>
        <translation>Zábava</translation>
    </message>
    <message>
        <source>Travel &amp; Events</source>
        <translation>Cestování a události</translation>
    </message>
    <message>
        <source>News &amp; Politics</source>
        <translation>Zprávy a politika</translation>
    </message>
    <message>
        <source>Pets &amp; Animals</source>
        <translation>Mazlíčci a jiná zvířata</translation>
    </message>
    <message>
        <source>Autos &amp; Vehicles</source>
        <translation>Nákladní a osobní auta</translation>
    </message>
</context>
<context>
    <name>UBZoomPalette</name>
    <message>
        <source>%1 x</source>
        <translation>%1 x</translation>
    </message>
</context>
<context>
    <name>WBClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Vymazat</translation>
    </message>
</context>
<context>
    <name>WBDownloadItem</name>
    <message>
        <source>KB</source>
        <translation>kB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>bytů</translation>
    </message>
    <message>
        <source>- %4 %5 remaining</source>
        <translation>– zbývá %4 %5 </translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minut(y)</translation>
    </message>
    <message>
        <source>Error opening saved file: %1</source>
        <translation>Chyba při otevírání uloženého souboru: %1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>sekund</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>Chyba při ukládání: %1</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>Stahování zrušeno: %1</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 z(o) %2 – zastaveno</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Uložit soubor</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation>%1 z(e) %2 (%3/sek) %4</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Chyba sítě: %1</translation>
    </message>
    <message>
        <source>?</source>
        <comment>unknown file size</comment>
        <translation>?</translation>
    </message>
</context>
<context>
    <name>WBDownloadManager</name>
    <message>
        <source>1 Download</source>
        <translation>1 stahování</translation>
    </message>
    <message>
        <source>%1 Downloads</source>
        <comment>always &gt;= 2</comment>
        <translation>%1 stahování</translation>
    </message>
</context>
<context>
    <name>WBHistoryModel</name>
    <message>
        <source>Title</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
</context>
<context>
    <name>WBHistoryTreeModel</name>
    <message>
        <source>%1 items</source>
        <translation>%1 položek</translation>
    </message>
    <message>
        <source>Earlier Today</source>
        <translation>dnes brzy ráno</translation>
    </message>
</context>
<context>
    <name>WBSearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
</context>
<context>
    <name>WBTabBar</name>
    <message>
        <source>Reload All Tabs</source>
        <translation>Obnovit všechny karty</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>Obnovit kartu</translation>
    </message>
    <message>
        <source>Clone Tab</source>
        <translation>Duplikovat kartu</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Zavřít kartu</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>Zavřít &amp;ostaní karty</translation>
    </message>
    <message>
        <source>New &amp;Tab</source>
        <translation>Nová &amp;karta</translation>
    </message>
</context>
<context>
    <name>WBTabWidget</name>
    <message>
        <source>(Untitled)</source>
        <translation>(Bez názvu)</translation>
    </message>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>Nedávno zavřené karty</translation>
    </message>
</context>
<context>
    <name>WBToolbarSearch</name>
    <message>
        <source>Recent Searches</source>
        <translation>Historie vyhledávání</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Vyhledat</translation>
    </message>
    <message>
        <source>No Recent Searches</source>
        <translation>Žádná historie vyhledávání</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation>Vymazat historii vyhledávání</translation>
    </message>
</context>
<context>
    <name>WBWebPage</name>
    <message>
        <source>PDF</source>
        <translation>PDF</translation>
    </message>
    <message>
        <source>Add to Current Document</source>
        <translation>Přidat do aktuálního dokumentu</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Stáhnout</translation>
    </message>
    <message>
        <source>Error loading page: %1</source>
        <translation>Chyba při nahrávání stránky: %1</translation>
    </message>
    <message>
        <source>Download PDF Document: would you prefer to download the PDF file or add it to the current OpenBoard document?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WBWebView</name>
    <message>
        <source>Open in New Tab</source>
        <translation>Otevřít v nové kartě</translation>
    </message>
</context>
<context>
    <name>XPDFRenderer</name>
    <message>
        <source>Processing...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>YouTubePublishingDialog</name>
    <message>
        <source>Title</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>YouTube Username</source>
        <translation>Uživatelské jméno na YouTube</translation>
    </message>
    <message>
        <source>YouTube Password</source>
        <translation>Heslo na YouTube</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategorie</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Publikovat podcast na YouTube</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation>Klíčová slova</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;By clicking &apos;Upload,&apos; you certify that you own all rights to the content or that you are authorized by the owner to make the content publicly available on YouTube, and that it otherwise complies with the YouTube Terms of Service located at &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;Kliknutím na &quot;Upload&quot; (Nahrať) potvrdzujete, že máte všetky práva k materiálu alebo že máte písomný súhlas vlastníka týchto práv na zverejnenie materiálu na sieti YouTube a že materiál je v súlade s podmienkami využívania služieb siete YouTube, ktorých aktuálne znenie sa nachádza na adrese  &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation type="unfinished">OpenBoard</translation>
    </message>
    <message>
        <source>Restore credentials on reboot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>brushProperties</name>
    <message>
        <source>Fine</source>
        <translation>Tenká</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Střední</translation>
    </message>
    <message>
        <source>Strong</source>
        <translation>Široká</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>Průhlednost</translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation>Šířka čáry</translation>
    </message>
    <message>
        <source>On Light Background</source>
        <translation>Na světlém pozadí</translation>
    </message>
    <message>
        <source>Pen is Pressure Sensitive</source>
        <translation>Pero je citlivé na tlak</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation>Na tmavém pozadí</translation>
    </message>
    <message>
        <source>Show preview circle from</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>px</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>capturePublishingDialog</name>
    <message>
        <source>Title</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
</context>
<context>
    <name>documentPublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="obsolete">Dialog</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="obsolete">Název</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation type="obsolete">E-mail</translation>
    </message>
    <message>
        <source>Author</source>
        <translation type="obsolete">Autor</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="obsolete">Popis</translation>
    </message>
</context>
<context>
    <name>documents</name>
    <message>
        <source>OpenBoard Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creation date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alphabetical order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort Order</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>preferencesDialog</name>
    <message>
        <source>Pen</source>
        <translation>Pero</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O programu</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Vodorovná</translation>
    </message>
    <message>
        <source>Display Text Under Button</source>
        <translation>Zobrazit text pod tlačítkem</translation>
    </message>
    <message>
        <source>Show Page with External Browser</source>
        <translation>Zobrazit stránku v externím prohlížeči</translation>
    </message>
    <message>
        <source>Default Settings</source>
        <translation>Výchozí nastavení</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Síť</translation>
    </message>
    <message>
        <source>Positioned at the Bottom (recommended for white boards)</source>
        <translation>Je umístěný dole (doporučeno pro interaktivní tabule)</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Zvýrazňovač</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Positioned at the Top (recommended for tablets)</source>
        <translation>Je umístěný na vrchu (doporučeno pro tablety)</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Virtuální klávesnice</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Domovská stránka:</translation>
    </message>
    <message>
        <source>Check software update at launch</source>
        <translation>Při spuštění programu vyhledat aktualizace</translation>
    </message>
    <message>
        <source>Software Update</source>
        <translation>Aktualizace programu</translation>
    </message>
    <message>
        <source>Keyboard button size:</source>
        <translation type="vanished">Velikost tlačítka klávesnice:</translation>
    </message>
    <message>
        <source>Stylus Palette</source>
        <translation>Paleta pro stylus</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Zobrazit</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Panel nástrojů</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Svislá</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>Předvolby</translation>
    </message>
    <message>
        <source>version : …</source>
        <translation>verze:...</translation>
    </message>
    <message>
        <source>Licences</source>
        <translation>Licence</translation>
    </message>
    <message>
        <source>Multi display</source>
        <translation>Víceobrazovkový režim</translation>
    </message>
    <message>
        <source>Show internal web page content on secondary screen or projector</source>
        <translation>Zobrazit obsah interní webové stránky na další obrazovce či dataprojektoru</translation>
    </message>
    <message>
        <source>Swap control display and view display</source>
        <translation>Vyměnit ovládací obrazovku za obrazovku pohledu</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mód</translation>
    </message>
    <message>
        <source>Mode to start in:</source>
        <translation>Mód začne na:</translation>
    </message>
    <message>
        <source>Board</source>
        <translation>Tabuli</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Ploše</translation>
    </message>
    <message>
        <source>Proxy User:</source>
        <translation>Proxy Uživatel:</translation>
    </message>
    <message>
        <source>Pass:</source>
        <translation>Heslo:</translation>
    </message>
    <message>
        <source>Credits</source>
        <translation>Zásluhy</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation type="unfinished">Na tmavém pozadí</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation type="unfinished">Průhlednost</translation>
    </message>
    <message>
        <source>On Light Background</source>
        <translation type="unfinished">Na světlém pozadí</translation>
    </message>
    <message>
        <source>Swap first and second view displays</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Built-in virtual keyboard button size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use system keyboard (recommended)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open-Sankoré Importer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check if Open-Sankoré data could be imported at launch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display date column on alphabetical sort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty trash for documents older than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PDF Rendering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Improve zoom execution time (can slightly affect rendering quality)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>trapFlashDialog</name>
    <message>
        <source>Trap flash</source>
        <translation>Přenést obsah ve flashi</translation>
    </message>
    <message>
        <source>Select a flash to trap</source>
        <translation>Vyberte flash, který chcete přenést</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation>about:blank</translation>
    </message>
    <message>
        <source>Application name</source>
        <translation>Název aplikace</translation>
    </message>
    <message>
        <source>Create Application</source>
        <translation>Vytvořit aplikaci</translation>
    </message>
</context>
</TS>
